@@ -10,6 +10,8 @@ import textwrap
 from mkdocs_include_markdown_plugin import process
 
 
+logger = logging.getLogger('mkdocs.plugins.mkdocs_include_markdown_plugin')
+
 TRUE_FALSE_STR_BOOL = {
     'true': True,
     'false': False,
@@ -21,7 +23,8 @@ TRUE_FALSE_BOOL_STR = {
 }
 
 BOOL_ARGUMENT_PATTERN = r'\w+'
-STR_ARGUMENT_PATTERN = r'([^"]|(?<=\\)")+'
+DOUBLE_QUOTED_STR_ARGUMENT_PATTERN = r'([^"]|(?<=\\)["])+'
+SINGLE_QUOTED_STR_ARGUMENT_PATTERN = r"([^']|(?<=\\)['])+"
 
 INCLUDE_TAG_REGEX = re.compile(
     rf'''
@@ -29,7 +32,7 @@ INCLUDE_TAG_REGEX = re.compile(
         \s*
         include
         \s+
-        "(?P<filename>{STR_ARGUMENT_PATTERN})"
+        (?:"(?P<double_quoted_filename>{DOUBLE_QUOTED_STR_ARGUMENT_PATTERN})")?(?:'(?P<single_quoted_filename>{SINGLE_QUOTED_STR_ARGUMENT_PATTERN})')?
         (?P<arguments>.*?)
         \s*
         %}}
@@ -44,9 +47,18 @@ INCLUDE_MARKDOWN_TAG_REGEX = re.compile(
 
 ARGUMENT_REGEXES = {
     # str
-    'start': re.compile(rf'start="({STR_ARGUMENT_PATTERN})"'),
-    'end': re.compile(rf'end="({STR_ARGUMENT_PATTERN})"'),
-    'exclude': re.compile(rf'exclude="({STR_ARGUMENT_PATTERN})"'),
+    'start': re.compile(
+            rf'start=(?:"({DOUBLE_QUOTED_STR_ARGUMENT_PATTERN})")?'
+            rf"(?:'({SINGLE_QUOTED_STR_ARGUMENT_PATTERN})')?",
+    ),
+    'end': re.compile(
+            rf'end=(?:"({DOUBLE_QUOTED_STR_ARGUMENT_PATTERN})")?'
+            rf"(?:'({SINGLE_QUOTED_STR_ARGUMENT_PATTERN})')?",
+    ),
+    'exclude': re.compile(
+            rf'exclude=(?:"({DOUBLE_QUOTED_STR_ARGUMENT_PATTERN})")?'
+            rf"(?:'({SINGLE_QUOTED_STR_ARGUMENT_PATTERN})')?",
+    ),
 
     # bool
     'rewrite-relative-urls': re.compile(
@@ -65,20 +77,60 @@ ARGUMENT_REGEXES = {
     'heading-offset': re.compile(r'heading-offset=(-?\d+)'),
 }
 
-logger = logging.getLogger('mkdocs.plugins.mkdocs_include_markdown_plugin')
+
+def parse_filename_argument(match):
+    raw_filename = match.group('double_quoted_filename')
+    if raw_filename is None:
+        raw_filename = match.group('single_quoted_filename')
+        if raw_filename is None:
+            filename = None
+        else:
+            filename = raw_filename.replace("\\'", "'")
+    else:
+        filename = raw_filename.replace('\\"', '"')
+    return filename, raw_filename
+
+
+def parse_string_argument(match):
+    value = match.group(1)
+    if value is None:
+        value = match.group(3)
+        if value is not None:
+            value = value.replace("\\'", "'")
+    else:
+        value = value.replace('\\"', '"')
+    return value
+
+
+def lineno_from_content_start(content, start):
+    return content[:start].count('\n') + 1
 
 
 def get_file_content(
     markdown,
     page_src_path,
     docs_dir,
-    includer_page_path,
     cumulative_heading_offset=0,
 ):
 
     def found_include_tag(match):
+        directive_match_start = match.start()
+
         _includer_indent = match.group('_includer_indent')
-        filename = match.group('filename').replace('\\"', '"')
+
+        filename, raw_filename = parse_filename_argument(match)
+        if filename is None:
+            lineno = lineno_from_content_start(
+                markdown,
+                directive_match_start,
+            )
+            logger.error(
+                "Found no path passed including with 'include'"
+                f' directive at {os.path.relpath(page_src_path, docs_dir)}'
+                f':{lineno}',
+            )
+            return ''
+
         arguments_string = match.group('arguments')
 
         if os.path.isabs(filename):
@@ -96,17 +148,29 @@ def get_file_content(
         if exclude_match is None:
             ignore_paths = []
         else:
-            exclude_string = exclude_match.group(1).replace('\\"', '"')
-            if os.path.isabs(exclude_string):
-                exclude_globstr = exclude_string
-            else:
-                exclude_globstr = os.path.realpath(
-                    os.path.join(
-                        os.path.abspath(os.path.dirname(page_src_path)),
-                        exclude_string,
-                    ),
+            exclude_string = parse_string_argument(exclude_match)
+            if exclude_string is None:
+                lineno = lineno_from_content_start(
+                    markdown,
+                    directive_match_start,
                 )
-            ignore_paths = glob.glob(exclude_globstr)
+                logger.error(
+                    "Invalid empty 'exclude' argument in 'include' directive"
+                    f' at {os.path.relpath(page_src_path, docs_dir)}:{lineno}',
+                )
+                ignore_paths = []
+            else:
+
+                if os.path.isabs(exclude_string):
+                    exclude_globstr = exclude_string
+                else:
+                    exclude_globstr = os.path.realpath(
+                        os.path.join(
+                            os.path.abspath(os.path.dirname(page_src_path)),
+                            exclude_string,
+                        ),
+                    )
+                ignore_paths = glob.glob(exclude_globstr)
 
         file_paths_to_include = process.filter_paths(
             glob.iglob(file_path_glob, recursive=True),
@@ -114,14 +178,17 @@ def get_file_content(
         )
 
         if not file_paths_to_include:
-            raise FileNotFoundError(
-                f'No files found including with \'{filename}\''
-                f' at {page_src_path}',
+            lineno = lineno_from_content_start(
+                markdown,
+                directive_match_start,
             )
+            logger.error(
+                f"No files found including '{raw_filename}'"
+                f' at {os.path.relpath(page_src_path, docs_dir)}'
+                f':{lineno}',
+            )
+            return ''
 
-        # handle options and regex modifiers
-
-        #   boolean options
         bool_options = {
             'preserve-includer-indent': {
                 'value': True,
@@ -137,28 +204,55 @@ def get_file_content(
             },
         }
 
-        for opt_name, opt_data in bool_options.items():
-            match = re.search(opt_data['regex'], arguments_string)
+        for arg_name, arg in bool_options.items():
+            match = re.search(arg['regex'], arguments_string)
             if match is None:
                 continue
             try:
-                bool_options[opt_name]['value'] = TRUE_FALSE_STR_BOOL[
-                    match.group(1) or TRUE_FALSE_BOOL_STR[opt_data['value']]
+                bool_options[arg_name]['value'] = TRUE_FALSE_STR_BOOL[
+                    match.group(1) or TRUE_FALSE_BOOL_STR[arg['value']]
                 ]
             except KeyError:
-                raise ValueError(
-                    f'Unknown value for \'{opt_name}\'. Possible values are:'
-                    ' true, false',
+                lineno = lineno_from_content_start(
+                    markdown,
+                    directive_match_start,
                 )
+                logger.error(
+                    f"Invalid value for '{arg_name}' argument of 'include'"
+                    f' directive at {os.path.relpath(page_src_path, docs_dir)}'
+                    f':{lineno}. Possible values are true or false.',
+                )
+                return ''
 
-        #   string options
         start_match = re.search(ARGUMENT_REGEXES['start'], arguments_string)
-        end_match = re.search(ARGUMENT_REGEXES['end'], arguments_string)
+        if start_match:
+            start = parse_string_argument(start_match)
+            if start is None:
+                lineno = lineno_from_content_start(
+                    markdown,
+                    directive_match_start,
+                )
+                logger.error(
+                    "Invalid empty 'start' argument in 'include' directive at "
+                    f'{os.path.relpath(page_src_path, docs_dir)}:{lineno}',
+                )
+        else:
+            start = None
 
-        start = None if not start_match else (
-            start_match.group(1).replace('\\"', '"')
-        )
-        end = None if not end_match else end_match.group(1).replace('\\"', '"')
+        end_match = re.search(ARGUMENT_REGEXES['end'], arguments_string)
+        if end_match:
+            end = parse_string_argument(end_match)
+            if end is None:
+                lineno = lineno_from_content_start(
+                    markdown,
+                    directive_match_start,
+                )
+                logger.error(
+                    "Invalid empty 'end' argument in 'include' directive at "
+                    f'{os.path.relpath(page_src_path, docs_dir)}:{lineno}',
+                )
+        else:
+            end = None
 
         text_to_include = ''
         expected_but_any_found = [start is not None, end is not None]
@@ -183,7 +277,6 @@ def get_file_content(
                 new_text_to_include,
                 file_path,
                 docs_dir,
-                page_src_path,
             )
 
             # trailing newlines right stripping
@@ -195,7 +288,7 @@ def get_file_content(
             if bool_options['dedent']:
                 new_text_to_include = textwrap.dedent(new_text_to_include)
 
-            # Includer indentation preservation
+            # includer indentation preservation
             if bool_options['preserve-includer-indent']['value']:
                 new_text_to_include = ''.join(
                     _includer_indent + line
@@ -215,18 +308,37 @@ def get_file_content(
                     for fpath in file_paths_to_include
                 ])
                 plural_suffix = 's' if len(file_paths_to_include) > 1 else ''
+                lineno = lineno_from_content_start(
+                    markdown,
+                    directive_match_start,
+                )
                 logger.warning(
-                    f"Delimiter {argname} '{value}' defined at"
-                    f' {os.path.relpath(includer_page_path, docs_dir)}'
-                    f' not detected in the file{plural_suffix}'
+                    f"Delimiter {argname} '{value}' of 'include'"
+                    f' directive at {os.path.relpath(page_src_path, docs_dir)}'
+                    f':{lineno} not detected in the file{plural_suffix}'
                     f' {readable_files_to_include}',
                 )
 
         return text_to_include
 
     def found_include_markdown_tag(match):
+        directive_match_start = match.start()
+
         _includer_indent = match.group('_includer_indent')
-        filename = match.group('filename').replace('\\"', '"')
+
+        filename, raw_filename = parse_filename_argument(match)
+        if filename is None:
+            lineno = lineno_from_content_start(
+                markdown,
+                directive_match_start,
+            )
+            logger.error(
+                "Found no path passed including with 'include-markdown'"
+                f' directive at {os.path.relpath(page_src_path, docs_dir)}'
+                f':{lineno}',
+            )
+            return ''
+
         arguments_string = match.group('arguments')
 
         if os.path.isabs(filename):
@@ -244,17 +356,29 @@ def get_file_content(
         if exclude_match is None:
             ignore_paths = []
         else:
-            exclude_string = exclude_match.group(1).replace('\\"', '"')
-            if os.path.isabs(exclude_string):
-                exclude_globstr = exclude_string
-            else:
-                exclude_globstr = os.path.realpath(
-                    os.path.join(
-                        os.path.abspath(os.path.dirname(page_src_path)),
-                        exclude_string,
-                    ),
+            exclude_string = parse_string_argument(exclude_match)
+            if exclude_string is None:
+                lineno = lineno_from_content_start(
+                    markdown,
+                    directive_match_start,
                 )
-            ignore_paths = glob.glob(exclude_globstr)
+                logger.error(
+                    "Invalid empty 'exclude' argument in 'include-markdown'"
+                    f' directive at {os.path.relpath(page_src_path, docs_dir)}'
+                    f':{lineno}',
+                )
+                ignore_paths = []
+            else:
+                if os.path.isabs(exclude_string):
+                    exclude_globstr = exclude_string
+                else:
+                    exclude_globstr = os.path.realpath(
+                        os.path.join(
+                            os.path.abspath(os.path.dirname(page_src_path)),
+                            exclude_string,
+                        ),
+                    )
+                ignore_paths = glob.glob(exclude_globstr)
 
         file_paths_to_include = process.filter_paths(
             glob.iglob(file_path_glob, recursive=True),
@@ -262,13 +386,17 @@ def get_file_content(
         )
 
         if not file_paths_to_include:
-            raise FileNotFoundError(
-                f'No files found using \'{filename}\' at {page_src_path}',
+            lineno = lineno_from_content_start(
+                markdown,
+                directive_match_start,
             )
+            logger.error(
+                f"No files found including '{raw_filename}' at"
+                f' {os.path.relpath(page_src_path, docs_dir)}'
+                f':{lineno}',
+            )
+            return ''
 
-        # handle options and regex modifiers
-
-        #   boolean options
         bool_options = {
             'rewrite-relative-urls': {
                 'value': True,
@@ -292,28 +420,59 @@ def get_file_content(
             },
         }
 
-        for opt_name, opt_data in bool_options.items():
-            match = re.search(opt_data['regex'], arguments_string)
+        for arg_name, arg in bool_options.items():
+            match = re.search(arg['regex'], arguments_string)
             if match is None:
                 continue
             try:
-                bool_options[opt_name]['value'] = TRUE_FALSE_STR_BOOL[
-                    match.group(1) or TRUE_FALSE_BOOL_STR[opt_data['value']]
+                bool_options[arg_name]['value'] = TRUE_FALSE_STR_BOOL[
+                    match.group(1) or TRUE_FALSE_BOOL_STR[arg['value']]
                 ]
             except KeyError:
-                raise ValueError(
-                    f'Unknown value for \'{opt_name}\'. Possible values are:'
-                    ' true, false',
+                lineno = lineno_from_content_start(
+                    markdown,
+                    directive_match_start,
                 )
+                logger.error(
+                    f"Invalid value for '{arg_name}' argument of"
+                    " 'include-markdown' directive at"
+                    f' {os.path.relpath(page_src_path, docs_dir)}'
+                    f':{lineno}. Possible values are true or false.',
+                )
+                return ''
 
-        #   string options
+        # start and end arguments
         start_match = re.search(ARGUMENT_REGEXES['start'], arguments_string)
-        end_match = re.search(ARGUMENT_REGEXES['end'], arguments_string)
+        if start_match:
+            start = parse_string_argument(start_match)
+            if start is None:
+                lineno = lineno_from_content_start(
+                    markdown,
+                    directive_match_start,
+                )
+                logger.error(
+                    "Invalid empty 'start' argument in 'include-markdown'"
+                    f' directive at {os.path.relpath(page_src_path, docs_dir)}'
+                    f':{lineno}',
+                )
+        else:
+            start = None
 
-        start = None if not start_match else (
-            start_match.group(1).replace('\\"', '"')
-        )
-        end = None if not end_match else end_match.group(1).replace('\\"', '"')
+        end_match = re.search(ARGUMENT_REGEXES['end'], arguments_string)
+        if end_match:
+            end = parse_string_argument(end_match)
+            if end is None:
+                lineno = lineno_from_content_start(
+                    markdown,
+                    directive_match_start,
+                )
+                logger.error(
+                    "Invalid empty 'end' argument in 'include-markdown'"
+                    f' directive at {os.path.relpath(page_src_path, docs_dir)}'
+                    f':{lineno}',
+                )
+        else:
+            end = None
 
         # heading offset
         offset = 0
@@ -353,7 +512,6 @@ def get_file_content(
                 new_text_to_include,
                 file_path,
                 docs_dir,
-                page_src_path,
             )
 
             # trailing newlines right stripping
@@ -400,10 +558,14 @@ def get_file_content(
                     for fpath in file_paths_to_include
                 ])
                 plural_suffix = 's' if len(file_paths_to_include) > 1 else ''
+                lineno = lineno_from_content_start(
+                    markdown,
+                    directive_match_start,
+                )
                 logger.warning(
-                    f"Delimiter {argname} '{value}' defined at"
-                    f' {os.path.relpath(includer_page_path, docs_dir)}'
-                    f' not detected in the file{plural_suffix}'
+                    f"Delimiter {argname} '{value}' of 'include-markdown'"
+                    f' directive at {os.path.relpath(page_src_path, docs_dir)}'
+                    f':{lineno} not detected in the file{plural_suffix}'
                     f' {readable_files_to_include}',
                 )
 
@@ -438,5 +600,4 @@ def on_page_markdown(markdown, page, docs_dir):
         markdown,
         page.file.abs_src_path,
         docs_dir,
-        page.file.abs_src_path,
     )
